#!/bin/sh

# This helper script will handle deploying a glue database
set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

#Run terraform to create glue database based on input contract definition
terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"
arnConfigMapName=${namingPrefix}-arn
terraform_get arn glueDatabaseArn
glueDatabaseName=$(jq '.glue_database_name.value' output.json | sed "s/\"//g")
# terraform_get glue_database_name glueDatabaseName
terraform_get glue_database_policy_arn accessPolicy

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${glueDatabaseArn}
  AccessPolicy: ${accessPolicy}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

# Create Glue tables based on input contract defintion if required.
if [ "${glueTableCreate}" == "true" ]; then
  cprint "Creating glue tables based on Input contract defined."
  glueDatabaseRegion=$(echo $glueDatabaseArn | cut -d':' -f 4)

  echo "Glue database name is: ${glueDatabaseName}"
  echo "The input config map in Env name: ${inputsConfigMapEnv}"
  tableNames=$(env | grep json | cut -d'=' -f1)

  if [ -n "${tableNames[@]}" ]; then
    echo "Proceeding with creation of glue tables in the database ${glueDatabaseName}"
    for tableName in ${tableNames[@]}; do
      echo "Get Table Definition from input Config map for ${tableName}"
      echo "kubectl -n ${infraNamespace} get cm ${inputsConfigMapEnv} -o \"jsonpath={ .data['${tableName}']}\""
      tableDefinitionInJson=$(kubectl -n ${infraNamespace} get cm ${inputsConfigMapEnv} -o "jsonpath={ .data['${tableName}']}")
      echo $tableDefinitionInJson | python -m json.tool > ${tableName}
      cat ${tableName}

      actualTableName=$(cat ${tableName} | jq -r '.TableInput.Name')
      getGlueTable=$(aws glue get-table --database-name ${glueDatabaseName} --name ${actualTableName} --region ${glueDatabaseRegion} 2>&1 || exit 0)
      if [[ $getGlueTable =~ "EntityNotFoundException" ]]; then
        echo "Output of getGlueTable call: ${getGlueTable}"
        echo "Running aws cli to create the glue table: aws glue create-table --database-name ${glueDatabaseName} --cli-input-json file://${tableName} --region ${glueDatabaseRegion} --debug"
        run_aws_cli=$(aws glue create-table --database-name ${glueDatabaseName} --cli-input-json file://${tableName} --region ${glueDatabaseRegion} --debug)
      else
        echo "Output of getGlueTable call: ${getGlueTable}"
        echo "Running aws cli to update the glue table: aws glue update-table --database-name ${glueDatabaseName} --cli-input-json file://${tableName} --region ${glueDatabaseRegion} --debug"
        run_aws_cli=$(aws glue update-table --database-name ${glueDatabaseName} --cli-input-json file://${tableName} --region ${glueDatabaseRegion} --debug)
      fi
    done
  else
    echo "Input contract is not defined to create glue tables. Hence skipping glue table creation"
  fi
fi

cprint "$0 done "
